from django.utils.translation import gettext_lazy as _

import django_tables2 as tables


class PurchasedItemsTable(tables.Table):
    sku = tables.Column(verbose_name=_("Art. No."))
    name = tables.Column(verbose_name=_("Item"), attrs={"td": {"class": "hero-col"}})
    tax_rate = tables.TemplateColumn(
        verbose_name=_("Tax Rate"),
        template_code="{{value}} %",
        attrs={"td": {"class": "right-align"}},
    )
    quantity = tables.Column(verbose_name=_("Qty."), attrs={"td": {"class": "right-align"}})
    price = tables.TemplateColumn(
        verbose_name=_("Gross"),
        template_code="{{value|floatformat:2}} {{record.currency}}",
        attrs={"td": {"class": "right-align"}},
    )

    class Meta:
        orderable = False


class TotalsTable(tables.Table):
    name = tables.Column(attrs={"td": {"class": "right-align hero-col"}})
    value = tables.TemplateColumn(
        template_code="{{value|floatformat:2}} {{record.currency}}",
        attrs={"td": {"class": "right-align"}},
    )

    class Meta:
        show_header = False
        orderable = False


class ClientsTable(tables.Table):
    class Meta:
        attrs = {"class": "responsive-table highlight"}

    name = tables.Column()

    edit = tables.LinkColumn(
        "edit_client_by_pk",
        args=[A("id")],
        verbose_name=_("Edit"),
        text=_("Edit"),
    )
