from django.views.generic import View
from django.shortcuts import render

from rules.contrib.views import PermissionRequiredMixin

from aleksis.core.views import RenderPDFView

from .tables import ClientsTable
from .forms import EditClientForm
from .models.base import Client
from .models.invoice import Invoice


class GetInvoicePDF(PermissionRequiredMixin, RenderPDFView):

    permission_required = "tezor.can_print_invoice"

    def get_context_data(self, *args, **kwargs):
        context = super().get_context_data(*args, **kwargs)
        invoice = Invoice.objects.get(id=self.kwargs["pk"])
        self.template_name = invoice.group.template_name
        context["invoice"] = invoice

        print(invoice.group.__dict__)
        return context

class ClientListView(PermissionRequiredMixin, SingleTableView):
    """Table of all clients."""

    model = Client
    table_class = ClientsTable
    permission_required = "teor.view_clients"
    template_name = "teor/client/list.html"


@method_decorator(never_cache, name="dispatch")
class ClientCreateView(PermissionRequiredMixin, AdvancedCreateView):
    """Create view for clients."""

    model = Client
    form_class = EditClientForm
    permission_required = "teor.add_clients"
    template_name = "teor/client/create.html"
    success_url = reverse_lazy("clients")
    success_message = _("The client has been created.")


@method_decorator(never_cache, name="dispatch")
class ClientEditView(PermissionRequiredMixin, AdvancedEditView):
    """Edit view for clients."""

    model = Client
    form_class = EditClientForm
    permission_required = "teor.edit_clients"
    template_name = "teor/client/edit.html"
    success_url = reverse_lazy("clients")
    success_message = _("The client has been saved.")
